@@ -10,27 +10,28 @@
 #include "sourcereference.h"
 #include "sourcereference_p.h"
 
+#include <KLocalizedString>
 #include <QString>
 #include <QUrl>
-#include <KLocalizedString>
 
 using namespace Okular;
 
 class SourceReference::Private
 {
-    public:
-        Private()
-            : row( 0 ), column( 0 )
-        {
-        }
+public:
+    Private()
+        : row(0)
+        , column(0)
+    {
+    }
 
-        QString filename;
-        int row;
-        int column;
+    QString filename;
+    int row;
+    int column;
 };
 
-SourceReference::SourceReference( const QString &fileName, int row, int column )
-    : d( new Private )
+SourceReference::SourceReference(const QString &fileName, int row, int column)
+    : d(new Private)
 {
     d->filename = fileName;
     d->row = row;
@@ -57,12 +58,12 @@ int SourceReference::column() const
     return d->column;
 }
 
-bool Okular::extractLilyPondSourceReference( const QUrl &url, QString *file, int *row, int *col )
+bool Okular::extractLilyPondSourceReference(const QUrl &url, QString *file, int *row, int *col)
 {
     // Example URL is: textedit:///home/foo/bar.ly:42:42:42
     // The three numbers are apparently: line:beginning of column:end of column
 
-    if ( url.scheme() != QStringLiteral("textedit") )
+    if (url.scheme() != QStringLiteral("textedit"))
         return false;
 
     // There can be more, in case the filename contains :
@@ -95,9 +96,9 @@ bool Okular::extractLilyPondSourceReference( const QUrl &url, QString *file, int
     return (!file->isEmpty());
 }
 
-QString Okular::sourceReferenceToolTip( const QString &source, int row, int col )
+QString Okular::sourceReferenceToolTip(const QString &source, int row, int col)
 {
-    Q_UNUSED( row );
-    Q_UNUSED( col );
-    return i18nc( "'source' is a source file", "Source: %1", source );
+    Q_UNUSED(row);
+    Q_UNUSED(col);
+    return i18nc("'source' is a source file", "Source: %1", source);
 }
