@@ -45,13 +45,6 @@ QUrl urlFromArg(const QString &_arg, FileExistFunc exist_func, const QString &pa
             url.setPath(path.left(hashIndex));
             url.setFragment(path.mid(hashIndex + 1));
         }
-    } else if (!url.fragment().isEmpty()) {
-        // make sure something like http://example.org/foo#bar.pdf is treated as a path name
-        // but something like http://example.org/foo.pdf#bar is foo.pdf plus an anchor "bar"
-        if (url.fragment().contains(QLatin1Char('.'))) {
-            url.setPath(url.path() + QLatin1Char('#') + url.fragment());
-            url.setFragment(QString());
-        }
     }
     if (!pageArg.isEmpty()) {
         url.setFragment(pageArg);
